SystemOrganization addCategory: #'Glamour-Tests'!

GLMSimpleTransmission subclass: #GLMMockSimpleTransmission
	instanceVariableNames: 'wasTransmited'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMMockSimpleTransmission classSide methodsFor: 'as yet unclassified' stamp: 'jorge.ressia 6/2/2009 21:24'!
new

	^super new initialize! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jorge.ressia 6/2/2009 21:24'!
initialize

	wasTransmited := false! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jorge.ressia 6/2/2009 21:26'!
transmit

	wasTransmited := true.
	super transmit.! !

!GLMMockSimpleTransmission methodsFor: 'testing' stamp: 'jorge.ressia 6/2/2009 21:23'!
wasTransmited
	^wasTransmited! !

TestCase subclass: #GLMBundleTransmissionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPorts 
	"Tests that the origins are set up properly and that their order is retained." 
	 
	| transmission | 
	transmission := GLMBundleTransmission new. 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port1; 
				value: 1). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port2; 
				value: 2). 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port3; 
				value: 3). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port4; 
				value: 4). 
	transmission destination: (GLMSimplePort new name: #port5). 
	self assert: transmission bundleOrigins size = 4. 
	transmission bundleOrigins 
		do: [:each | self assert: (each isKindOf: GLMBundleOrigin)]. 
	self assert: (transmission bundleOrigins at: 1) port name = #port1. 
	self assert: (transmission bundleOrigins at: 2) port name = #port2. 
	self assert: (transmission bundleOrigins at: 3) port name = #port3. 
	self assert: (transmission bundleOrigins at: 4) port name = #port4. 
	self assert: transmission origins size = 4. 
	transmission origins 
		do: [:each | self assert: (each isKindOf: GLMSimplePort)]. 
	self assert: (transmission origins at: 1) name = #port1. 
	self assert: (transmission origins at: 2) name = #port2. 
	self assert: (transmission origins at: 3) name = #port3. 
	self assert: (transmission origins at: 4) name = #port4. 
	self assert: transmission activeOrigins size = 2. 
	transmission activeOrigins 
		do: [:each | self assert: (each isKindOf: GLMSimplePort)]. 
	self assert: (transmission activeOrigins at: 1) name = #port1. 
	self assert: (transmission activeOrigins at: 2) name = #port3. 
	self assert: transmission passiveOrigins size = 2. 
	transmission passiveOrigins 
		do: [:each | self assert: (each isKindOf: GLMSimplePort)]. 
	self assert: (transmission passiveOrigins at: 1) name = #port2. 
	self assert: (transmission passiveOrigins at: 2) name = #port4. 
	self assert: (transmission destination isKindOf: GLMSimplePort). 
	self assert: transmission destination name = #port5! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPresentations 
	"Tests that the presentations are set up correctly." 
	 
	| transmission presentation1 presentation2 presentation3 | 
	transmission := GLMBundleTransmission new. 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port1; 
				value: 1). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port2; 
				value: 2). 
	transmission destination: (GLMSimplePort new name: #port3). 
	presentation1 := GLMPresentation new title: 'presentation1'. 
	presentation2 := GLMPresentation new title: 'presentation2'. 
	presentation3 := GLMPresentation new title: 'presentation3'. 
	transmission addPresentation: presentation1. 
	transmission addPresentation: presentation2. 
	transmission addPresentation: presentation3.	"Test correct setup" 
	self assert: transmission presentations size = 3. 
	self assert: (transmission presentations at: 1) == presentation1. 
	self assert: (transmission presentations at: 2) == presentation2. 
	self assert: (transmission presentations at: 3) == presentation3! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTransmitting 
	"Tests that the origins are set up properly and that their order is retained." 
	 
	| transmission | 
	transmission := GLMBundleTransmission new. 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port1; 
				value: 1). 
	transmission destination: (GLMSimplePort new name: #port5). 
	self assert: transmission value = 1. 
	self assert: transmission destination value isNil. 
	transmission transmit. 
	self assert: transmission destination value = 1. 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port2; 
				value: 2). 
	transmission 
		addActiveOrigin: 
			((GLMSimplePort new) 
				name: #port3; 
				value: 3). 
	transmission 
		addPassiveOrigin: 
			((GLMSimplePort new) 
				name: #port4; 
				value: 4). 
	self assert: transmission value = (GLMMultiValue withAll: #(1 2 3 4)). 
	transmission transmit. 
	self 
		assert: 
			transmission destination value = (GLMMultiValue withAll: #(1 2 3 4))! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditions 
	"Tests that the transmission is triggered only when the active origins change." 
	 
	| transmission port1 port2 | 
	transmission := GLMBundleTransmission new. 
	port1 := GLMPort new name: #port1. 
	port2 := GLMPort new name: #port2. 
	transmission addActiveOrigin: port1. 
	transmission addPassiveOrigin: port2. 
	transmission destination: (GLMPort new name: #port3). 
	self assert: (transmission originatesAt: port1). 
	self assert: (transmission originatesAt: port2) not! !

!GLMBundleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditionsWithParentPort 
	 
	| transmission presentation | 
	transmission := GLMBundleTransmission new. 
	presentation := GLMPresentation new. 
	transmission 
		addActiveOrigin: 
			((GLMParentPort new) 
				presentation: presentation; 
				name: #port1; 
				yourself). 
	self 
		assert: 
			(transmission 
				originatesAt: 
					((GLMParentPort new) 
						presentation: presentation; 
						name: #port1; 
						yourself)). 
	self assert: (transmission originatesAt: (presentation pane port: #port1))! !

TestCase subclass: #GLMExplicitBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 20:39'!
testJumpstartTransmission 
	 
	| browser presentation | 
	browser := GLMExplicitBrowser new. 
	presentation := GLMPresentation new. 
	browser addNewPane. 
	browser 
		addJumpstart: 
			((GLMBundleTransmission new) 
				destination: (browser panes first port: #entity); 
				addPresentation: presentation; 
				yourself). 
	self assert: (browser panes first port: #entity) value isNil. 
	self assert: browser panes first presentations isEmpty. 
	(browser pane port: #entity) value: #foo. 
	self assert: (browser panes first port: #entity) value = #foo. 
	self assert: browser panes first presentations size = 1. 
	self assert: browser panes first presentations first == presentation! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:04'!
testParentPort 
	 
	| browser outerPort1 outerPort2 transmission1 transmission2 | 
	browser := GLMExplicitBrowser new. 
	browser addNewPane. 
	GLMTestPane new addPresentation: browser. 
	outerPort1 := (GLMParentPort new) 
		presentation: browser; 
		name: #outerPort1; 
		yourself. 
	outerPort2 := (GLMParentPort new) 
		presentation: browser; 
		name: #outerPort2; 
		yourself.	"Capturing" 
	browser 
		addTransmission: 
			(transmission1 := (GLMMockSimpleTransmission new) 
				origin: outerPort1; 
				destination: (browser panes first port: #innerPort1); 
				yourself).	"Publishing" 
	browser 
		addTransmission: 
			((transmission2 := GLMMockSimpleTransmission new) 
				origin: (browser panes first port: #innerPort2); 
				destination: outerPort2; 
				yourself). 
	(browser pane port: #outerPort1) value: 42. 
	self assert: (browser panes first port: #innerPort1) value = 42. 
	self assert: transmission1 wasTransmited.
	self deny: transmission2 wasTransmited.
	"self assert: (browser pane port: #outerPort1) seenTransmissions size = 0. "
	"self 
		assert: 
			((browser pane port: #outerPort1) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). 
	self 
		assert: 
			((browser pane port: #outerPort1) seenTransmissions first origin isKindOf: 
					GLMSimplePort). 
	self 
		assert: 
			(browser pane port: #outerPort1) seenTransmissions first destination 
				== (browser pane port: #outerPort1). "
	"self 
		assert: 
			(browser panes first port: #innerPort1) seenTransmissions size = 1. 
	self 
		assert: 
			(browser panes first port: #innerPort1) seenTransmissions first 
				== browser transmissions first. "
	(browser panes first port: #innerPort2) value: 43. 
	self assert: (browser pane port: #outerPort2) value = 43. 
	"self 
		assert: 
			(browser panes first port: #innerPort2) seenTransmissions size = 0. "
	"self 
		assert: 
			((browser panes first port: #innerPort2) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). 
	self 
		assert: 
			((browser panes first port: #innerPort2) seenTransmissions first origin 
				isKindOf: GLMSimplePort). 
	self 
		assert: 
			(browser panes first port: #innerPort2) seenTransmissions first destination 
				== (browser panes first port: #innerPort2). "
	"self assert: (browser pane port: #outerPort2) seenTransmissions size = 1. 
	self 
		assert: 
			(browser pane port: #outerPort2) seenTransmissions first 
				== browser transmissions last"! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 20:45'!
testSetup 
	 
	| browser pane1 pane2 transmission | 
	browser := GLMExplicitBrowser new. 
	
	pane1 := browser addNewPane. 
	pane2 := browser addNewPane. 
	transmission := (GLMSimpleTransmission new) 
		origin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		yourself.  
	browser addTransmission: transmission. 
	self assert: browser panes size = 2. 
	self assert: browser transmissions size = 1. 
	self assert: browser panes first == pane1. 
	self assert: browser panes last == pane2. 
	self assert: pane1 browser == browser. 
	self assert: pane2 browser == browser. 
	self assert: browser transmissions first == transmission! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:27'!
testSimpleTransmission 
	 
	| browser pane1 pane2 presentation1 presentation2 transmission announcement | 
	browser := GLMExplicitBrowser new. 
	presentation1 := GLMPresentation new. 
	presentation2 := GLMPresentation new. 
	pane1 := browser addNewPane. 
	pane2 := browser addNewPane. 
	pane1 addPresentation: presentation1. 
	pane2 addPresentation: presentation2. 
	transmission := (GLMMockSimpleTransmission new) 
		origin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		yourself. 
	browser addTransmission: transmission. 
	announcement := nil. 
	presentation2 
		when: GLMContextChanged 
		do: [:ann | announcement := ann]. 
	presentation1 selection: 'foo'. 
	self assert: transmission wasTransmited.
	"self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	self assert: (pane2 port: #entity) seenTransmissions size = 1." 
	"self 
		assert: (pane1 port: #selection) seenTransmissions first ~~ transmission. "
	"self assert: (pane2 port: #entity) seenTransmissions first == transmission. "
	self assert: (pane1 port: #selection) value = 'foo'. 
	self assert: (pane2 port: #entity) value = 'foo'. 
	self assert: announcement notNil! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 5/30/2009 12:24'!
testTransmissionBundle 
	 
	| browser pane1 pane2 pane3 presentation1 presentation2 transmission | 
	browser := GLMExplicitBrowser new. 
	presentation1 := GLMPresentation new. 
	presentation2 := GLMPresentation new. 
	pane1 := GLMTestPane new. 
	pane2 := GLMTestPane new. 
	pane3 := GLMTestPane new. 
	pane1 addPresentation: GLMPresentation new. 
	pane2 addPresentation: GLMPresentation new. 
	pane3 addPresentation: presentation1. 
	transmission := (GLMBundleTransmission new) 
		addActiveOrigin: (pane1 port: #selection); 
		addPassiveOrigin: (pane2 port: #selection); 
		destination: (pane3 port: #entity); 
		addPresentation: presentation2; 
		yourself. 
	browser addPane: pane1. 
	browser addPane: pane2. 
	browser addPane: pane3. 
	browser addTransmission: transmission. 
	self assert: pane3 presentations size = 1. 
	self assert: pane3 presentations first == presentation1.	"The first should not trigger any transmission (passive) 
	but the second should." 
	pane2 presentations first selection: #foo. 
	pane1 presentations first selection: #bar. 
	self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	self assert: (pane2 port: #selection) seenTransmissions size = 0. 
	"self 
		assert: (pane1 port: #selection) seenTransmissions first ~~ transmission. 
	self 
		assert: (pane2 port: #selection) seenTransmissions first ~~ transmission." 
	self assert: (pane3 port: #entity) seenTransmissions size = 1. 
	"self assert: (pane3 port: #entity) seenTransmissions first ~~ transmission." 
	"self assert: (pane3 port: #entity) seenTransmissions first value = nil. "
	self assert: (pane3 port: #entity) seenTransmissions last == transmission. 
	self 
		assert: 
			(pane3 port: #entity) value = (GLMMultiValue withAll: #(#bar #foo)). 
	self assert: pane3 presentations size = 1. 
	self assert: pane3 presentations first == presentation2! !

!GLMExplicitBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 5/30/2009 12:20'!
testTriggeringConditions 
	 
	| browser pane1 pane2 transmission | 
	browser := GLMExplicitBrowser new. 
	browser pane: GLMTestPane new. 
	pane1 := GLMTestPane new. 
	pane2 := GLMTestPane new. 
	transmission := (GLMSimpleTransmission new) 
		origin: (pane1 port: #selection); 
		destination: (pane2 port: #entity); 
		yourself. 
	browser addPane: pane1. 
	browser addPane: pane2. 
	browser addTransmission: transmission. 
	self assert: (pane1 port: #selection) seenTransmissions isEmpty. 
	self assert: (pane2 port: #entity) seenTransmissions isEmpty. 
	(pane1 port: #selection) value: 12. 
	self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	"self 
		assert: 
			((pane1 port: #selection) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). "
	self assert: (pane2 port: #entity) seenTransmissions size = 1. 
	self assert: (pane2 port: #entity) seenTransmissions first == transmission.	"Setting the same value should re-publish but not trigger inner transmissions." 
	(pane1 port: #selection) value: 12. 
	self assert: (pane1 port: #selection) seenTransmissions size = 0. 
	"self 
		assert: 
			((pane1 port: #selection) seenTransmissions first isKindOf: 
					GLMSimpleTransmission). "
	"self 
		assert: 
			((pane1 port: #selection) seenTransmissions last isKindOf: 
					GLMSimpleTransmission). "
	self assert: (pane2 port: #entity) seenTransmissions size = 1. 
	self assert: (pane2 port: #entity) seenTransmissions first == transmission! !

TestCase subclass: #GLMFinderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMFinderTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPaneCreation 
	 
	| browser | 
	browser := GLMFinder new. 
	browser addPresentation: (GLMPresentation new title: 'presentation1'). 
	self assert: browser panes isEmpty.	"Outer entity changed." 
	(browser pane port: #entity) value: #value1. 
	self assert: browser panes size = 1. 
	self assert: browser panes first browser == browser. 
	self assert: (browser panes first port: #entity) value = #value1. 
	self assert: browser panes first presentations size = 1. 
	self 
		assert: browser panes first presentations first title = 'presentation1'. 
	self 
		assert: 
			browser panes first presentations first ~~ browser presentations first.	"First pane selection changed." 
	(browser panes first port: #selection) value: #value2. 
	self assert: browser panes size = 2. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value2. 
	self 
		assert: browser panes last presentations first title = 'presentation1'. 
	self 
		assert: 
			browser panes last presentations first ~~ browser presentations first. 
	self 
		assert: 
			browser panes last presentations first 
				~~ browser panes first presentations first.	"Second pane selection changed." 
	(browser panes last port: #selection) value: #value3. 
	self assert: browser panes size = 3. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value3.	"First pane selection changed again." 
	(browser panes first port: #selection) value: #value4. 
	self assert: browser panes size = 2. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value4.	"Outer entity changed again." 
	(browser pane port: #entity) value: #value5. 
	self assert: browser panes size = 1. 
	self assert: browser panes last browser == browser. 
	self assert: (browser panes last port: #entity) value = #value5! !

!GLMFinderTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPortPublishing 
	 
	| browser | 
	browser := GLMFinder new. 
	(browser pane port: #entity) value: #value1. 
	self assert: browser panes size = 1. 
	self assert: browser pane ports size = 1. 
	self assert: (browser pane port: #entity) value = #value1. 
	(browser panes first port: #selection) value: #value2. 
	self assert: browser panes size = 2. 
	self assert: browser pane ports size = 2. 
	self assert: (browser pane port: #entity) value = #value1. 
	self assert: (browser pane port: #selection) value = #value2. 
	(browser panes last port: #selection) value: #value3. 
	self assert: browser panes size = 3. 
	self assert: browser pane ports size = 2. 
	self assert: (browser pane port: #entity) value = #value1. 
	self assert: (browser pane port: #selection) value = #value3. 
	(browser panes first port: #hover) value: #value4. 
	self assert: browser panes size = 3. 
	self assert: browser pane ports size = 3. 
	self assert: (browser pane port: #entity) value = #value1. 
	self assert: (browser pane port: #selection) value = #value3. 
	self assert: (browser pane port: #hover) value = #value4! !

TestCase subclass: #GLMFlexiblePresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMFlexiblePresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 9/11/2009 14:46'!
testDefault
	| browser |
	browser := GLMTableLayoutBrowser new.
	browser startOn: #(1 2 3).
	self assert: (browser panes first presentations first isKindOf: GLMFlexiblePresentation).
	browser startOn: 1.
	self assert: (browser panes first presentations first isKindOf: GLMFlexiblePresentation).! !

!GLMFlexiblePresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 9/11/2009 15:23'!
testDynamic
	| browser childBrowser |
	childBrowser := GLMFinder new.
	browser := GLMTableLayoutBrowser new.
	browser column: #one.
	browser showOn: #one; using: [
		browser custom: (GLMDynamicPresentation new display: [childBrowser]) ].
	browser startOn: 42.
	self assert: browser panes first presentations first currentPresentation == childBrowser.
	self assert: childBrowser pane == browser panes first ! !

TestCase subclass: #GLMFormattedPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMFormattedPresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 9/9/2009 01:10'!
testFormat
	| presentation |
	presentation := GLMFormatedPresentation new.
	presentation format: [:c | c ].
	self assert: (presentation formatedDisplayValueOf: 1) = 1.
	presentation entity: 41.
	presentation format: [:a :c | a + c ].
	self assert: (presentation formatedDisplayValueOf: 1) = 42.
	presentation entity: (GLMMultiValue with: 20 with: 21).
	presentation format: [:a :b :c | a + b + c ].
	self assert: (presentation formatedDisplayValueOf: 1) = 42.
! !

TestCase subclass: #GLMListPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMListPresentationTest methodsFor: 'as yet unclassified' stamp: 'tg 8/25/2009 16:01'!
testToSend
	| list |
	list := GLMListPresentation new.
	list selectionTransformation: [ :x | x + 1 ].
	list entity: #(1 #to: 41 ).
	list selection: 41.
	self assert: list selection = 42! !

TestCase subclass: #GLMNestedBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMNestedBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:43'!
testChangeInnerSelection 
	"Tests setting the selection of an inner pane from the oustide. 
 
	The test sets up a browser with two panes. The first contains a 
	list of numbers, the second a browser which again contains one 
	pane with a list of the same numbers. When the selection in the 
	first pane changes, we want the same number to be selected in 
	the second pane. 
 
	To achieve this, we pull in a port on the second pane and copy 
	it to the inner pane using a simple transmission." 
	 
	| browser1 browser2 list1 list2 | 
	browser1 := GLMExplicitBrowser new. 
	browser2 := GLMExplicitBrowser new. 
	list1 := GLMListPresentation new. 
	list2 := GLMListPresentation new. 
	browser1 addNewPane. 
	browser1 addNewPane. 
	browser2 addNewPane. 
	browser1 panes first addPresentation: list1. 
	browser1 panes last addPresentation: browser2. 
	browser2 panes first addPresentation: list2. 
	browser1 
		addTransmission: 
			((GLMSimpleTransmission new) 
				origin: (browser1 panes first port: #selection); 
				destination: (browser1 panes last port: #innerSelection); 
				yourself). 
	browser2 
		addTransmission: 
			((GLMSimpleTransmission new) 
				origin: 
						((GLMParentPort new) 
								presentation: browser2; 
								name: #innerSelection; 
								yourself); 
				destination: (browser2 panes first port: #selection); 
				yourself). 
	list1 entity: #(1 2 3). 
	list2 entity: #(1 2 3). 
	list1 selection: 1. 
	self assert: list2 selection = 1. 
	list1 selection: 2. 
	self assert: list2 selection = 2! !

!GLMNestedBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:44'!
testEntityPropogation 
	"This tests the order in which presentations and values are updated. 
 
	This is of importance as, in this test, we add a browser to a pane when a 
	certain port of that pane gets updated using a BundleTransmission but this 
	browser has a transmission from its #outer pane that refers to the same 
	port.  In such a case we want the presentation to be set first so that it can 
	be notified when the outer port changes." 
	 
	| browser1 browser2 presentation | 
	browser1 := GLMExplicitBrowser new. 
	browser2 := GLMExplicitBrowser new. 
	presentation := GLMPresentation new. 
	browser1 addNewPane. 
	browser2 addNewPane.	"Jumpstart presentation for outer browser." 
	browser1 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser1; 
								name: #entity; 
								yourself); 
				destination: (browser1 panes first port: #entity); 
				addPresentation: browser2; 
				yourself).	"Jumpstart presentation for inner browser." 
	browser2 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser2; 
								name: #entity; 
								yourself); 
				destination: (browser2 panes first port: #entity); 
				addPresentation: presentation; 
				yourself). 
	self assert: (browser1 pane port: #entity) value isNil. 
	self assert: browser1 panes size = 1. 
	self assert: (browser1 panes first port: #entity) value isNil. 
	self assert: browser1 panes first presentations isEmpty. 
	self assert: browser2 panes size = 1. 
	self assert: (browser2 panes first port: #entity) value isNil. 
	self assert: browser2 panes first presentations isEmpty. 
	(browser1 pane port: #entity) value: 42. 
	self assert: (browser1 pane port: #entity) value = 42. 
	self assert: browser1 panes size = 1. 
	self assert: (browser1 panes first port: #entity) value = 42. 
	self assert: browser1 panes first presentations size = 1. 
	self assert: browser1 panes first presentations first == browser2. 
	self assert: browser2 panes size = 1. 
	self assert: (browser2 panes first port: #entity) value = 42. 
	self assert: browser2 panes first presentations size = 1. 
	self assert: browser2 panes first presentations first == presentation! !

!GLMNestedBrowserTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:44'!
testEntityPropogationAnnouncements 
	"This tests the order in which announcements are raised in nested browsers. 
 
	This is of importance as, in this test, we add a browser to a pane when a 
	certain port of that pane gets updated using a BundleTransmission but this 
	browser has a transmission from its #outer pane that refers to the same 
	port.  In such a case we want the presentation to be set first so that it can 
	be notified when the outer port changes. 
 
	This is a sister test to testEntityPropogation that ensures that the 
	announcements are raised in the right order and not redundantly." 
	 
	| browser1 browser2 presentation announcements | 
	browser1 := GLMExplicitBrowser new. 
	browser2 := GLMExplicitBrowser new. 
	presentation := GLMPresentation new. 
	browser1 pane. 
	browser1 addNewPane. 
	browser2 addNewPane. 
	announcements := OrderedCollection new. 
	self assert: browser1 pane presentations size = 1. 
	self assert: browser1 pane presentations first == browser1. 
	browser1 whenContextChanged: [:ann | announcements addLast: ann]. 
	browser2 whenContextChanged: [:ann | announcements addLast: ann]. 
	presentation whenContextChanged: [:ann | announcements addLast: ann]. 
	browser1 pane 
		whenPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser1 panes first 
		whenPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser2 panes first 
		whenPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser1 pane 
		whenMatchingPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser1 panes first 
		whenMatchingPresentationsChanged: [:ann | announcements addLast: ann]. 
	browser2 panes first 
		whenMatchingPresentationsChanged: [:ann | announcements addLast: ann].	"Jumpstart presentation for outer browser." 
	browser1 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser1; 
								name: #entity; 
								yourself); 
				destination: (browser1 panes first port: #entity); 
				addPresentation: browser2; 
				yourself).	"Jumpstart presentation for inner browser." 
	browser2 
		addTransmission: 
			((GLMBundleTransmission new) 
				addActiveOrigin: 
						((GLMParentPort new) 
								presentation: browser2; 
								name: #entity; 
								yourself); 
				destination: (browser2 panes first port: #entity); 
				addPresentation: presentation; 
				yourself). 
	self assert: announcements isEmpty. 
	(browser1 pane port: #entity) value: 42. 
	self assert: announcements size = 8.	"1. The outer browser's outer pane changes its value." 
	self assert: ((announcements at: 1) isKindOf: GLMContextChanged). 
	self assert: (announcements at: 1) presentation == browser1. 
	self assert: (announcements at: 1) property = #entity. 
	self assert: (announcements at: 1) value = 42.	"2. The jumpstart transmission of the outer browser is triggered, updating the presentations..." 
	self assert: ((announcements at: 2) isKindOf: GLMPresentationsChanged). 
	self assert: (announcements at: 2) pane == browser1 panes first. 
	self assert: (announcements at: 2) oldPresentations isEmpty. 
	self assert: (announcements at: 2) presentations size = 1. 
	self assert: (announcements at: 2) presentations first == browser2.	"3. ...and then the context." 
	self assert: ((announcements at: 3) isKindOf: GLMContextChanged). 
	self assert: (announcements at: 3) presentation == browser2. 
	self assert: (announcements at: 3) property = #entity. 
	self assert: (announcements at: 3) value = 42.	"4. The jumpstart transmission of the inner browser is triggered, updating the presentations..." 
	self assert: ((announcements at: 4) isKindOf: GLMPresentationsChanged). 
	self assert: (announcements at: 4) pane == browser2 panes first. 
	self assert: (announcements at: 4) oldPresentations isEmpty. 
	self assert: (announcements at: 4) presentations size = 1. 
	self assert: (announcements at: 4) presentations first == presentation.	"5. ...and then the context." 
	self assert: ((announcements at: 5) isKindOf: GLMContextChanged). 
	self assert: (announcements at: 5) presentation == presentation. 
	self assert: (announcements at: 5) property = #entity. 
	self assert: (announcements at: 5) value = 42.	"6. Due to the context change of 5, the innermost presentation now matches." 
	self 
		assert: ((announcements at: 6) isKindOf: GLMMatchingPresentationsChanged). 
	self assert: (announcements at: 6) pane == browser2 panes first. 
	self assert: (announcements at: 6) oldMatchingPresentations isEmpty. 
	self assert: (announcements at: 6) matchingPresentations size = 1. 
	self 
		assert: (announcements at: 6) matchingPresentations first == presentation.	"7. Due to the context change of 3, the inner browser now matches." 
	self 
		assert: ((announcements at: 7) isKindOf: GLMMatchingPresentationsChanged). 
	self assert: (announcements at: 7) pane == browser1 panes first. 
	self assert: (announcements at: 7) oldMatchingPresentations isEmpty. 
	self assert: (announcements at: 7) matchingPresentations size = 1. 
	self assert: (announcements at: 7) matchingPresentations first == browser2.	"8. Due to the context change of 1, the outer browser now matches." 
	self 
		assert: ((announcements at: 8) isKindOf: GLMMatchingPresentationsChanged). 
	self assert: (announcements at: 8) pane == browser1 pane. 
	self assert: (announcements at: 8) oldMatchingPresentations isEmpty. 
	self assert: (announcements at: 8) matchingPresentations size = 1. 
	self assert: (announcements at: 8) matchingPresentations first == browser1! !

TestCase subclass: #GLMNoBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMNoBrowserTest methodsFor: 'as yet unclassified' stamp: 'jorge.ressia 6/3/2009 08:35'!
testCreation

	self deny: GLMNoBrowser new isNil.
	self assert: (GLMNoBrowser new) == GLMNoBrowser new! !

TestCase subclass: #GLMPaneTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 20:26'!
testCreation
	 
	| aPane | 
	aPane := GLMPane named: 1 in: 2. 
	self assert: aPane name = 1.
	self assert: aPane browser = 2.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:13'!
testIn
	 
	| aPane | 
	aPane := GLMPane in: 1.
	self assert: aPane name = aPane defaultName.
	self assert: aPane browser = 1.
	self assert: aPane ports isEmpty.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:26'!
testNamed
	 
	| aPane | 
	aPane := GLMPane named: 1.
	self assert: aPane name = 1.
	self assert: aPane browser = GLMNoBrowser new.
	self assert: aPane ports isEmpty.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:05'!
testNamedIn
	 
	| aPane | 
	aPane := GLMPane named: 1 in: 2. 
	self assert: aPane name = 1.
	self assert: aPane browser = 2.
	self assert: aPane ports isEmpty.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:06'!
testPorts 
	 
	| pane port | 
	pane := GLMPane named: 'test'. 
	self assert: pane ports isEmpty. 
	port := pane port: #foo. 
	self assert: pane ports size = 1. 
	self assert: pane ports first == port. 
	self assert: (pane port: #foo) == port! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:15'!
testPortsInmmutability
	 
	| aPane ports | 
	aPane := GLMPane in: 1.
	self assert: aPane ports isEmpty.
	ports := aPane ports.
	ports add: 1.
	self assert: ports size = 1.
	self assert: aPane ports isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'tg 9/11/2009 16:04'!
testPresentationConditions 
	 
	| pane presentation1 presentation2 presentation3 | 
	pane := GLMPane named: 'test'. 
	presentation1 := GLMPresentation new condition: [:first :second | first = 1 and: [second = 2]]. 
	presentation2 := GLMPresentation new condition: [:first | first = #foo]. 
	presentation3 := GLMPresentation new useExplicitNotNil. 
	pane addPresentation: presentation1. 
	pane addPresentation: presentation2. 
	pane addPresentation: presentation3. 
	(pane port: #entity) value: (GLMMultiValue withAll: #(1 2)). 
	self assert: pane matchingPresentations size = 2. 
	self assert: pane matchingPresentations first == presentation1. 
	self assert: pane matchingPresentations last == presentation3. 
	(pane port: #entity) value: (GLMMultiValue withAll: #(#foo 2)). 
	self assert: pane matchingPresentations size = 2. 
	self assert: pane matchingPresentations first == presentation2. 
	self assert: pane matchingPresentations last == presentation3. 
	(pane port: #entity) value: (GLMMultiValue withAll: #(nil 2)). 
	self assert: pane matchingPresentations size = 1! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:07'!
testPresentations 
	 
	| pane presentation announcement | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	self assert: pane presentations isEmpty. 
	announcement := nil. 
	pane whenPresentationsChanged: [:ann | announcement := ann]. 
	pane addPresentation: presentation. 
	self assert: pane presentations size = 1. 
	self assert: pane presentations first == presentation. 
	self assert: presentation pane == pane. 
	self assert: announcement notNil! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 09:16'!
testPresentationsInmmutability
	 
	| aPane presentations | 
	aPane := GLMPane in: 1.
	self assert: aPane presentations isEmpty.
	presentations := aPane presentations.
	presentations add: 1.
	self assert: presentations size = 1.
	self assert: aPane presentations isEmpty.! !

!GLMPaneTest methodsFor: 'tests' stamp: 'jorge.ressia 6/3/2009 08:07'!
testSimplePresentations 
	 
	| pane presentation announcement | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	self assert: pane presentations isEmpty. 
	announcement := nil. 
	pane whenPresentationsChanged: [:ann | announcement := ann]. 
	pane addPresentation: presentation. 
	self assert: pane presentations size = 1. 
	self assert: pane presentations first == presentation. 
	self assert: presentation pane == pane. 
	self assert: announcement notNil! !

TestCase subclass: #GLMPortEventTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPortEventTest methodsFor: 'testing' stamp: 'jorge.ressia 5/30/2009 12:59'!
testCreation
	| anEvent |
	anEvent := GLMPortEvent 
		on: 1
		previouslyValued: 2.
	self assert: anEvent port = 1.
	self assert: anEvent oldValue = 2.
	self assert: anEvent transmissionContext isEmpty.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'jorge.ressia 5/30/2009 12:54'!
testCreationWithTransmissionContext
	| anEvent |
	anEvent := GLMPortEvent 
		on: 1
		previouslyValued: 2
		in: 3.
	self assert: anEvent port = 1.
	self assert: anEvent oldValue = 2.
	self assert: anEvent transmissionContext = 3.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'tg 9/18/2009 13:59'!
testInterdependentPanes
	|browser outerCount oneCount |
	outerCount := 0.
	oneCount := 0.
	browser := GLMTableLayoutBrowser new.
	browser column: #one; column: #two; column: #three.
	browser showOn: #one; using: [
		browser list
			display: [:x | 1 to: x]].
	browser showOn: #two; from: #one; using: [
		browser list
			display: [:x | 1 to: x*2]].
	browser showOn: #three; from: #two; using: [
		browser list
			display: [:x | 1 to: x*3];
			update: #focus on: $f entitled: 'Focus' with: [:list | list selection] ].
	browser sendTo: #outer->#focus from: #three->#focus with: [:x | outerCount := outerCount + 1].
	browser sendTo: #one->#selection from: #outer->#focus with: [:x | oneCount := oneCount + 1].
	browser startOn: 5.
	((browser paneNamed: #one) port: #selection) value: 3.
	((browser paneNamed: #two) port: #selection) value: 6.
	((browser paneNamed: #three) port: #selection) value: 12.
	((browser paneNamed: #three) port: #focus) value: 12.
	self assert: oneCount = 1.
	self assert: outerCount = 1.! !

!GLMPortEventTest methodsFor: 'testing' stamp: 'jorge.ressia 5/30/2009 12:02'!
testPortName
	| anEvent |
	anEvent := GLMPortEvent 
		on: ((GLMPort new) name: '1'; yourself)
		previouslyValued: 2.
	self assert: anEvent portName = '1'.
! !

TestCase subclass: #GLMPortTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPortTest methodsFor: 'tests' stamp: 'jorge.ressia 5/30/2009 12:21'!
testPanePort 
	 
	| port | 
	port := GLMTestPane new port: #port1. 
	self assert: port seenTransmissions isEmpty. 
	port value: 42. 
	self assert: port seenTransmissions size = 0. 
	"self assert: port seenTransmissions first origin value = 42. 
	self assert: port seenTransmissions first origin ~= port. 
	self assert: port seenTransmissions first destination == port. 
	self assert: port value = 42"! !

!GLMPortTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testParentPort 
	 
	| presentation port | 
	presentation := GLMPresentation new. 
	port := (GLMParentPort new) 
		name: #port; 
		presentation: presentation. 
	port value: 42. 
	self assert: (presentation pane port: #port) value = 42. 
	(presentation pane port: #port) value: 43. 
	self assert: port value = 43! !

!GLMPortTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPortEquality 
	 
	| presentation port | 
	presentation := GLMPresentation new. 
	port := (GLMParentPort new) 
		name: #port; 
		presentation: presentation. 
	self assert: port = (presentation pane port: #port). 
	self assert: (presentation pane port: #port) = port. 
	self assert: port hash = (presentation pane port: #port) hash. 
	self assert: (presentation pane port: #port) hash = port hash! !

!GLMPortTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testSimplePort 
	 
	| port | 
	port := GLMSimplePort new. 
	port name: #foo. 
	port value: 42. 
	self assert: port name = #foo. 
	self assert: port value = 42. 
	self assert: port hasPane not! !

TestCase subclass: #GLMPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMPresentationTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 23:44'!
testAnnouncement 
	 
	| pane presentation announcement | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	pane addPresentation: presentation. 
	announcement := nil. 
	presentation 
		when: GLMContextChanged 
		do: [:ann | announcement := ann]. 
	(pane port: #entity) value: 42. 
	self assert: announcement notNil. 
	self assert: announcement property = #entity. 
	self assert: announcement value = 42! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 23:44'!
testContext 
	 
	| pane presentation | 
	pane := GLMPane named: 'test'. 
	presentation := GLMPresentation new. 
	pane addPresentation: presentation. 
	presentation selection: 42. 
	self assert: (pane port: #selection) value = 42. 
	(pane port: #entity) value: 'foo'. 
	self assert: presentation entity = 'foo'! !

!GLMPresentationTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testDisplay 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	presentation entity: #foo. 
	self assert: presentation displayValue = #foo. 
	presentation entity: #(#foo #bar). 
	self assert: presentation displayValue = #(#foo #bar). 
	presentation entity: (GLMMultiValue withAll: #(#foo #bar)). 
	self assert: presentation displayValue = #foo. 
	presentation transformation: [:first :second | (first , second) asSymbol]. 
	self assert: presentation displayValue = #foobar! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'DamienCassou 9/10/2009 19:53'!
testImplicitNotNilMultipleValues
	"
	self debug: #testImplicitNotNilMultipleValues"
	| presentation | 
	presentation := GLMPresentation new. 
	presentation useImplicitNotNil.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil nil)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(1 nil)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(nil 1)).
	self assert: presentation matches not.
	(presentation pane port: #entity) value: (GLMMultiValue withAll: #(1 2)).
	self assert: presentation matches.! !

!GLMPresentationTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testMatching 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	self assert: presentation usesImplicitNotNil. 
	(presentation pane port: #entity) value: nil. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches. 
	presentation useExplicitNotNil. 
	self assert: presentation usesImplicitNotNil not. 
	(presentation pane port: #entity) value: nil. 
	self assert: presentation matches. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches. 
	presentation condition: [:x | x > 1]. 
	presentation useImplicitNotNil. 
	self assert: presentation usesImplicitNotNil. 
	(presentation pane port: #entity) value: nil. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 2. 
	self assert: presentation matches. 
	presentation useExplicitNotNil. 
	(presentation pane port: #entity) value: 1. 
	self assert: presentation matches not. 
	(presentation pane port: #entity) value: 2. 
	self assert: presentation matches. 
	self assert: presentation usesImplicitNotNil not. 
	[(presentation pane port: #entity) value: nil. 
	presentation matches. 
	self signalFailure: 'Should have raised error'] 
		on: MessageNotUnderstood 
		do: 
			[:err |  
			self assert: err message selector = #>. 
			self assert: err message arguments = (Array with: 1)]! !

!GLMPresentationTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testSetup 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	self assert: presentation pane notNil. 
	self assert: (presentation pane presentations includes: presentation)! !

!GLMPresentationTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTitle 
	 
	| presentation | 
	presentation := GLMPresentation new. 
	presentation entity: #foo. 
	self assert: presentation titleValue = 'foo'. 
	presentation entity: '4'. 
	presentation title: [:x | x , '2']. 
	self assert: presentation titleValue = '42'. 
	presentation entity: (GLMMultiValue withAll: #('4' '3')). 
	presentation title: [:first :second | first , second]. 
	self assert: presentation titleValue = '43'! !

!GLMPresentationTest methodsFor: 'tests' stamp: 'tg 8/25/2009 16:01'!
testToSend
	| presentation |
	presentation := GLMPresentation new.
	presentation selection: #foo.
	self assert: presentation selection = #foo.
	presentation selection: #(#foo #bar ).
	self assert: presentation selection = #(#foo #bar ).
	presentation selection: (GLMMultiValue withAll: #(#foo #bar )).
	self assert: presentation selection = #foo.
	presentation selectionTransformation: [ :first :second | (first , second) asSymbol ].
	presentation selection: (GLMMultiValue withAll: #(#foo #bar )).
	self assert: presentation selection = #foobar! !

TestCase subclass: #GLMScriptingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 9/11/2009 19:36'!
testActionDefinition 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser column: #one. 
	browser showOn: #one; using: [
		browser text act: [] entitled: ''.
		browser list act: [] entitled: ''.
		browser tree act: [] entitled: '']. 
	browser startOn: #(42).
	browser panes first presentations do: [:each | 
		self assert: each actions size = 1]! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'jorge.ressia 5/22/2009 15:39'!
testComplexFinderBrowser 
	 
	| browser | 
	browser := GLMFinder new. 
	(browser list) 
		title: 'Presentation1'; 
		display: [:each | 1 to: each]. 
	browser 
		fromPrevious: #selection; 
		passivelyFromPrevious: #highlight; 
		using: 
				[(browser list) 
						title: 'Presentation2'; 
						display: [:selection :highlight | 1 to: selection + highlight]]. 
	browser startOn: 42. 
	self assert: browser presentations size = 1. 
	self assert: browser presentations first title = 'Presentation1'. 
	self assert: browser transmissions size = 1. 
	self assert: browser transmissions last origins size = 2. 
	self assert: browser transmissions last presentations size = 1. 
	self 
		assert: 
			browser transmissions last presentations first title = 'Presentation2'. 
	self assert: (browser panes first port: #entity) value = 42. 
	(browser panes first port: #highlight) value: 43. 
	(browser panes first port: #selection) value: 41. 
	self assert: browser panes size = 2. 
	self assert: browser panes last presentations last displayValue size = 84. 
	self assert: browser panes last presentations size = 2! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testConditionalPresentation 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		showOn: #two; 
		from: #one; 
		using: 
				[browser text when: [:x | x = 42]. 
					browser list when: [:x | x > 42]]. 
	((browser paneNamed: #one) port: #selection) value: 42. 
	self assert: (browser paneNamed: #two) matchingPresentations size = 1. 
	self 
		assert: 
			((browser paneNamed: #two) matchingPresentations first isKindOf: 
					GLMTextPresentation). 
	((browser paneNamed: #one) port: #selection) value: 43. 
	self assert: (browser paneNamed: #two) matchingPresentations size = 1. 
	self 
		assert: 
			((browser paneNamed: #two) matchingPresentations first isKindOf: 
					GLMListPresentation)! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 8/4/2009 14:58'!
testDynamicActions
	| browser |
	browser := GLMTableLayoutBrowser new.
	browser column: #one.
	browser
		showOn: #one;
		using: [ browser list
				display: [ :x | 1 to: x ];
				actions: [ :list | 
					(1 to: list selection) collect: 
						[ :index | 
						GLMAction new
							action: [ index ];
							title: 'Action' , index printString;
							yourself ] ] ].
	browser startOn: 42.
	(browser panes first port: #selection) value: 3.
	self assert: browser panes first presentations first dynamicActions size = 3.
	(browser panes first port: #selection) value: 5.
	self assert: browser panes first presentations first dynamicActions size = 5! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testEntityInUpdateAction 
	 
	| browser inputFromActionBlock | 
	browser := GLMTableLayoutBrowser new. 
	browser column: #one. 
	browser 
		showOn: #one; 
		using: 
				[browser text 
						update: #foo 
						on: $m 
						with: [:list :input | inputFromActionBlock := input]]. 
	browser startOn: 42. 
	browser panes first presentations first actions first 
		actOn: browser panes first presentations first. 
	self assert: inputFromActionBlock = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testNestedBrowser 
	 
	| browser innerBrowser | 
	browser := GLMTableLayoutBrowser new. 
	browser column: #one. 
	innerBrowser := GLMTableLayoutBrowser new. 
	innerBrowser column: #innerOne. 
	innerBrowser 
		showOn: #innerOne; 
		using: [innerBrowser text]. 
	browser 
		showOn: #one; 
		using: [browser custom: innerBrowser]. 
	browser startOn: 42. 
	self assert: ((browser paneNamed: #one) port: #entity) value = 42. 
	self 
		assert: ((innerBrowser paneNamed: #innerOne) port: #entity) value = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testNestedBrowserWithExplicitTransmission 
	 
	| browser innerBrowser | 
	browser := GLMTableLayoutBrowser new. 
	browser column: #one. 
	innerBrowser := GLMTableLayoutBrowser new. 
	innerBrowser column: #innerOne. 
	innerBrowser 
		showOn: #innerOne; 
		from: #outer -> #entity; 
		using: [innerBrowser text]. 
	browser 
		showOn: #one; 
		using: [browser custom: innerBrowser]. 
	browser startOn: 42. 
	self assert: ((browser paneNamed: #one) port: #entity) value = 42. 
	self 
		assert: ((innerBrowser paneNamed: #innerOne) port: #entity) value = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testPublishing 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser column: #classes. 
	browser 
		sendToOutside: #selectedClass 
		from: #classes -> #selection. 
	browser 
		sendTo: #classes -> #highlight 
		fromOutside: #highlightedClass. 
	(browser panes first port: #selection) value: 42. 
	self assert: (browser pane port: #selectedClass) value = 42. 
	self assert: (browser panes first port: #selection) value = 42. 
	(browser pane port: #highlightedClass) value: 43. 
	self assert: (browser pane port: #highlightedClass) value = 43. 
	self assert: (browser panes first port: #highlight) value = 43. 
	(browser panes first port: #highlight) value: 44. 
	self assert: (browser pane port: #highlightedClass) value = 43. 
	self assert: (browser panes first port: #highlight) value = 44. 
	(browser pane port: #selectedClass) value: 45. 
	self assert: (browser pane port: #selectedClass) value = 45. 
	self assert: (browser panes first port: #selection) value = 42! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 9/6/2009 00:37'!
testPublishingToOutsideFinder
	 
	| innerBrowser finder | 
	finder := GLMFinder new.
	innerBrowser := GLMTableLayoutBrowser new.
	innerBrowser column: #any.
	innerBrowser 
		sendToOutside: #somePort
		from: #any -> #selection. 
	innerBrowser 
		sendToOutside: #selection
		from: #any -> #selection.
	finder custom: innerBrowser.
	finder startOn: 43.
	(finder panes first presentations first panes first port: #selection) value: 42.
	self assert: (innerBrowser pane port: #selection) value isNil.
	self assert: (finder panes first port: #selection) value = 42.
	self assert: (finder panes last port: #entty) value = 42.
	! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 21:52'!
testReferences 
	 
	| browser pane1 | 
	browser := GLMExplicitBrowser new.  
 	pane1 := browser addNewPaneNamed: #pane1.
	self 
		assert: (browser resolveOriginPort: #pane1) == (pane1 port: #selection). 
	self 
		assert: (browser resolveOriginPort: #pane1 -> #foo) == (pane1 port: #foo). 
	self 
		assert: (browser resolveDestinationPort: #pane1) == (pane1 port: #entity). 
	self 
		assert: 
			(browser resolveDestinationPort: #pane1 -> #foo) == (pane1 port: #foo). 
	self assert: ((browser resolveOriginPort: #outer) isKindOf: GLMParentPort). 
	self assert: (browser resolveOriginPort: #outer) presentation == browser. 
	self assert: (browser resolveOriginPort: #outer) name = #selection. 
	self 
		assert: 
			((browser resolveOriginPort: #outer -> #foo) isKindOf: GLMParentPort). 
	self 
		assert: 
			(browser resolveOriginPort: #outer -> #foo) presentation == browser. 
	self assert: (browser resolveOriginPort: #outer -> #foo) name = #foo. 
	self 
		assert: 
			((browser resolveDestinationPort: #outer) isKindOf: GLMParentPort). 
	self 
		assert: (browser resolveDestinationPort: #outer) presentation == browser. 
	self assert: (browser resolveDestinationPort: #outer) name = #entity. 
	self 
		assert: 
			((browser resolveDestinationPort: #outer -> #foo) isKindOf: GLMParentPort). 
	self 
		assert: 
			(browser resolveDestinationPort: #outer -> #foo) presentation == browser. 
	self assert: (browser resolveDestinationPort: #outer -> #foo) name = #foo! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testScriptingDefaults 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser startOn: 42. 
	self assert: browser panes size = 1. 
	self assert: browser jumpstartTransmissions size = 1. 
	self 
		assert: 
			browser jumpstartTransmissions first destination 
				= (browser panes first port: #entity)! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testSimpleTransmission 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		sendTo: #two -> #port2 
		from: #one -> #port1. 
	self assert: browser transmissions size = 1. 
	self assert: (browser transmissions first isKindOf: GLMSimpleTransmission). 
	self 
		assert: 
			browser transmissions first origin 
				= ((browser paneNamed: #one) port: #port1). 
	self 
		assert: 
			browser transmissions first destination 
				= ((browser paneNamed: #two) port: #port2)! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testStartTransmission 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		showOn: #one; 
		using: [browser list]. 
	self assert: browser transmissions isEmpty. 
	self assert: browser jumpstartTransmissions size = 1. 
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	browser startOn: 15. 
	self assert: (browser paneNamed: #one) presentations size = 1. 
	self assert: (browser paneNamed: #two) presentations isEmpty! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testStartWithOnlyJumpStart 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two. 
	browser 
		showOn: #one; 
		using: [browser list]. 
	browser 
		showOn: #two; 
		from: #one; 
		using: [browser text]. 
	self assert: browser transmissions size = 1. 
	self assert: browser jumpstartTransmissions size = 1. 
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	browser startOn: #(15 25 35). 
	self assert: (browser paneNamed: #one) presentations size = 1. 
	self assert: (browser paneNamed: #one) matchingPresentations size = 1. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	self assert: (browser paneNamed: #two) matchingPresentations isEmpty! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testThreePanesTransmissions 
	 
	| browser one two | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two; 
		column: #three. 
	browser 
		showOn: #three; 
		from: #one; 
		passivelyFrom: #two; 
		using: 
				[browser text 
						display: 
							[:x :y |  
							one := x. 
							two := y]]. 
	self assert: browser jumpstartTransmissions isEmpty. 
	self assert: browser transmissions size = 1. 
	self assert: browser transmissions first passiveOrigins size = 1. 
	self assert: browser transmissions first activeOrigins size = 1. 
	((browser paneNamed: #two) port: #selection) value: 15. 
	self assert: ((browser paneNamed: #two) port: #selection) value = 15. 
	self assert: ((browser paneNamed: #three) port: #entity) value isNil. 
	((browser paneNamed: #one) port: #selection) value: 20. 
	self assert: ((browser paneNamed: #one) port: #selection) value = 20. 
	self assert: ((browser paneNamed: #three) port: #entity) value first = 20. 
	self assert: ((browser paneNamed: #three) port: #entity) value last = 15! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 9/11/2009 15:28'!
testTransmissionWithTwoOrigins 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two; 
		column: #three. 
	browser 
		showOn: #three; 
		from: #one; 
		from: #two; 
		using: [browser text]. 
	((browser paneNamed: #one) port: #selection) value: 42. 
	self assert: ((browser paneNamed: #three) port: #entity) value first = 42. 
	self assert: ((browser paneNamed: #three) port: #entity) value last = nil. 
	self assert: (browser paneNamed: #three) presentations size = 1. 
	self assert: (browser paneNamed: #three) matchingPresentations size = 0. 
	((browser paneNamed: #two) port: #selection) value: 43. 
	self assert: ((browser paneNamed: #three) port: #entity) value first = 42. 
	self assert: ((browser paneNamed: #three) port: #entity) value last = 43. 
	self assert: (browser paneNamed: #three) matchingPresentations size = 1! !

!GLMScriptingTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTwoTransmissionsWithOnlyOneEvent 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser 
		column: #one; 
		column: #two; 
		column: #three. 
	browser 
		showOn: #two; 
		from: #one; 
		using: [browser list]. 
	browser 
		showOn: #three; 
		from: #two; 
		using: [browser text]. 
	self assert: browser transmissions size = 2. 
	self assert: browser jumpstartTransmissions size = 0. 
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations isEmpty. 
	self assert: (browser paneNamed: #three) presentations isEmpty. 
	((browser paneNamed: #one) port: #selection) value: 42. 
	self assert: ((browser paneNamed: #two) port: #entity) value = 42. 
	self assert: (browser paneNamed: #one) presentations isEmpty. 
	self assert: (browser paneNamed: #two) presentations size = 1. 
	self assert: (browser paneNamed: #two) matchingPresentations size = 1. 
	self assert: (browser paneNamed: #three) presentations isEmpty. 
	self assert: (browser paneNamed: #three) matchingPresentations isEmpty! !

!GLMScriptingTest methodsFor: 'tests' stamp: 'tg 8/4/2009 15:18'!
testUpdateAction 
	 
	| browser | 
	browser := GLMTableLayoutBrowser new. 
	browser column: #one; column: #two. 
	browser showOn: #one; using: [
		browser list update: #foo on: $m with: [:list :input | 42]]. 
	browser showOn: #two; from: #one -> #foo; using: [browser text]. 
	browser startOn: #(1 2 3). 
	self assert: browser panes first presentations size = 1. 
	self assert: browser panes last presentations isEmpty. 
	browser panes first presentations first actions first 
		actOn: browser panes first presentations first. 
	self assert: browser panes second presentations size = 1. 
	self assert: browser panes second presentations first entity = 42! !

TestCase subclass: #GLMSimpleTransmissionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMSimpleTransmissionTest methodsFor: 'tests' stamp: 'jorge.ressia 6/2/2009 23:45'!
testSimple 
	 
	| pane1 pane2 transmission | 
	pane1 := GLMPane named: 'test1'. 
	pane2 := GLMPane named: 'test2'. 
	transmission := (GLMSimpleTransmission new) 
		origin: (pane1 port: #output); 
		destination: (pane2 port: #input); 
		yourself. 
	(pane1 port: #output) value: 42. 
	self assert: (pane1 port: #output) value = 42. 
	self assert: (pane2 port: #input) value = nil. 
	transmission transmit. 
	self assert: (pane1 port: #output) value = 42. 
	self assert: (pane2 port: #input) value = 42! !

!GLMSimpleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditions 
	"Tests that the transmission is triggered only when the origin changes." 
	 
	| transmission port1 port2 | 
	transmission := GLMSimpleTransmission new. 
	port1 := GLMPort new name: #port1. 
	port2 := GLMPort new name: #port2. 
	transmission origin: port1. 
	transmission destination: port2. 
	self assert: (transmission originatesAt: port1). 
	self assert: (transmission originatesAt: port2) not. 
	self assert: (transmission originatesAt: GLMPort new) not! !

!GLMSimpleTransmissionTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testTriggerConditionsWithParentPort 
	 
	| transmission presentation | 
	transmission := GLMSimpleTransmission new. 
	presentation := GLMPresentation new. 
	transmission 
		origin: 
			((GLMParentPort new) 
				presentation: presentation; 
				name: #port1; 
				yourself). 
	self 
		assert: 
			(transmission 
				originatesAt: 
					((GLMParentPort new) 
						presentation: presentation; 
						name: #port1; 
						yourself)). 
	self assert: (transmission originatesAt: (presentation pane port: #port1))! !

TestCase subclass: #GLMTableLayoutTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTableLayoutTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testComplex 
	 
	| layout | 
	layout := GLMTableLayoutBrowser new. 
	layout 
		addColumn: 
			[:column |  
			column addRow: #second. 
			column addRow: #third. 
			column addRow: #fourth. 
			column 
				addRow: 
					[:row |  
					row addColumn: #fifth. 
					row addColumn: #sixth]]. 
	layout addColumn: #first. 
	self assert: layout cell children size = 2. 
	self assert: layout cell children first children size = 4. 
	self assert: layout cell children first children last children size = 2! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testOneSimpleColumnAndOneNested 
	 
	| layout | 
	layout := GLMTableLayoutBrowser new. 
	layout 
		addColumn: 
			[:column |  
			column addRow: #second. 
			column addRow: #third. 
			column addRow: #fourth]. 
	layout addColumn: #first. 
	self assert: layout cell children size = 2. 
	self assert: layout cell children first children size = 3! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testOneSimpleRowAndOneNested 
	 
	| layout | 
	layout := GLMTableLayoutBrowser new. 
	layout addRow: #first. 
	layout 
		addRow: 
			[:row |  
			row addColumn: #second. 
			row addColumn: #third. 
			row addColumn: #fourth]. 
	self assert: layout cell children size = 2. 
	self assert: layout cell children last children size = 3! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testSimpleColumns 
	 
	| layout | 
	layout := GLMTableLayoutBrowser new. 
	layout addColumn: #first. 
	layout addColumn: #second. 
	self assert: layout cell children size = 2! !

!GLMTableLayoutTest methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testSimpleRows 
	 
	| layout | 
	layout := GLMTableLayoutBrowser new. 
	layout addRow: #first. 
	layout addRow: #second. 
	self assert: layout cell children size = 2. 
	self assert: layout cell isColumn. 
	self assert: layout cell children first isRow! !

TestCase subclass: #GLMTestExtensions
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTestExtensions methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testGlamourValue 
	"Block closure" 
	 
	self assert: ([#foo] glamourValue: #(1 2)) = #foo. 
	self 
		assert: ([:first | Array with: first] glamourValue: #(1 2)) = #(#(1 2)). 
	self 
		assert: 
			([:first :second | Array with: first with: second] glamourValue: #(1 2)) = 
					#(#(1 2) nil). 
	self 
		assert: 
			([:first :second | Array with: first with: second] 
				glamourValue: (GLMMultiValue with: 1 with: 2)) = #(1 2).	"Symbol" 
	self assert: (#yourself glamourValueWithArgs: #(1 2)) = 1. 
	self assert: (#yourself glamourValueWithArgs: #()) = nil	"self assert: (#yourself glamourValue: (MultiValue with: 1 with: 2)) = 1."! !

!GLMTestExtensions methodsFor: 'tests' stamp: ' 4/5/09 22:18'!
testGlamourValueWithArgs 
	"Block closure" 
	 
	self assert: ([#foo] glamourValueWithArgs: #(1 2)) = #foo. 
	self 
		assert: 
			([:first | Array with: first] glamourValueWithArgs: #(1 2)) = #(1). 
	self 
		assert: 
			([:first :second | Array with: first with: second] glamourValueWithArgs: 
					#(1 2)) = #(1 2). 
	self 
		assert: 
			([:first :second :third | Array with: first with: second with: third] 
				glamourValueWithArgs: #(1 2)) = #(1 2 nil).	"Symbol" 
	self assert: (#yourself glamourValueWithArgs: #(1 2)) = 1. 
	self assert: (#yourself glamourValueWithArgs: #()) = nil! !

TestCase subclass: #GLMTextPresentationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTextPresentationTest methodsFor: 'testing' stamp: 'tg 8/7/2009 01:25'!
testSelectedText
	| presentation |
	presentation := GLMTextPresentation new.
	self assert: (presentation selectedText = '').
	presentation selectedTextBlock: ['selection'].
	self assert: (presentation selectedText = 'selection')! !

GLMPane subclass: #GLMTestPane
	instanceVariableNames: 'seenTransmissions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTestPane classSide methodsFor: 'private' stamp: 'jorge.ressia 6/3/2009 08:55'!
new

	^super new initialize! !

!GLMTestPane classSide methodsFor: 'private' stamp: ' 4/5/09 22:18'!
portClass 
	 
	^GLMTestPort! !

!GLMTestPane methodsFor: 'accessing' stamp: 'jorge.ressia 6/2/2009 23:35'!
browser

	browser isNil ifTrue: [^GLMNoBrowser new].
	^browser! !

!GLMTestPane methodsFor: 'accessing' stamp: 'jorge.ressia 6/2/2009 21:37'!
browser: aBrowser 
	browser := aBrowser! !

!GLMTestPane methodsFor: 'accessing' stamp: 'jorge.ressia 6/3/2009 08:57'!
initialize

	ports := OrderedCollection new.
	presentations := OrderedCollection new.! !

GLMPanePort subclass: #GLMTestPort
	instanceVariableNames: 'seenTransmissions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Tests'!

!GLMTestPort methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
receive: aTransmission 
	 
	self seenTransmissions addLast: aTransmission. 
	^super receive: aTransmission! !

!GLMTestPort methodsFor: 'accessing' stamp: ' 4/5/09 22:18'!
seenTransmissions 
	 
	^seenTransmissions ifNil: [seenTransmissions := OrderedCollection new]! !
